@@ -1,4 +1,4 @@
-# $Id: /mirror/coderepos/lang/perl/Queue-Q4M/trunk/lib/Queue/Q4M.pm 64066 2008-06-24T04:52:43.377517Z daisuke  $
+# $Id: /mirror/coderepos/lang/perl/Queue-Q4M/trunk/lib/Queue/Q4M.pm 64779 2008-07-02T10:07:30.009782Z daisuke  $
 #
 # Copyright (c) 2008 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -57,7 +57,7 @@ no Moose;
 use DBI;
 use SQL::Abstract;
 
-our $VERSION = '0.00004';
+our $VERSION = '0.00005';
 
 
 sub BUILD
@@ -116,8 +116,8 @@ sub next
     my @tables = 
         grep { !/^\d+$/ }
         map  {
-            s/\[.*$//;
-            $_
+            (my $v = $_) =~ s/:.*$//;
+            $v
         }
         @args
     ;
@@ -380,6 +380,10 @@ These are defined as part of Moose infrastructure
 
 Copyright (c) 2008 Daisuke Maki E<lt>daisuke@endeworks.jpE<gt>
 
+=head1 CONTRIBUTOR
+
+Taro Funaki 
+
 =head1 LICENSE
 
 This program is free software; you can redistribute it and/or modify it
@@ -387,4 +391,4 @@ under the same terms as Perl itself.
 
 See http://www.perl.com/perl/misc/Artistic.html
 
-=cut
\ No newline at end of file
+=cut
